/**
 * This is represented as an object instead of an enum due to limitations with TypeScript enums. (We
 * want this type to be a child of the `BitFlag` type.)
 *
 * @enum
 * @notExported
 * @rename EntityPartition
 */
declare const EntityPartitionInternal: {
    /** 1 << 0 (1) */
    readonly FAMILIAR: number;
    /** 1 << 1 (2) */
    readonly BULLET: number;
    /** 1 << 2 (4) */
    readonly TEAR: number;
    /** 1 << 3 (8) */
    readonly ENEMY: number;
    /** 1 << 4 (16) */
    readonly PICKUP: number;
    /** 1 << 5 (32) */
    readonly PLAYER: number;
    /**
     * 1 << 6 (64)
     *
     * @deprecated The `Isaac.FindInRadius` method will only work with entities that have collision.
     *             Since effects do not have collision, they will never be returned. Thus, this enum
     *             is useless.
     */
    readonly EFFECT: number;
};
type EntityPartitionValue = BitFlag & {
    readonly __entityPartitionBrand: symbol;
};
type EntityPartitionType = {
    readonly [K in keyof typeof EntityPartitionInternal]: EntityPartitionValue;
};
export declare const EntityPartition: EntityPartitionType;
export type EntityPartition = EntityPartitionType[keyof EntityPartitionType];
export declare const EntityPartitionZero: BitFlags<EntityPartitionValue>;
export {};
//# sourceMappingURL=EntityPartition.d.ts.map