/**
 * This is represented as an object instead of an enum due to limitations with TypeScript enums. (We
 * want this type to be a child of the `BitFlag` type.)
 *
 * @enum
 * @notExported
 * @rename LevelCurse
 */
declare const LevelCurseInternal: {
    /** 1 << -1 (0) */
    readonly NONE: 0;
    /**
     * 1 << 0 (1)
     *
     * Corresponds to `CurseID.DARKNESS` (1).
     */
    readonly DARKNESS: int;
    /**
     * 1 << 1 (2)
     *
     * Corresponds to `CurseID.LABYRINTH` (2).
     */
    readonly LABYRINTH: int;
    /**
     * 1 << 2 (4)
     *
     * Corresponds to `CurseID.LOST` (3).
     */
    readonly LOST: int;
    /**
     * 1 << 3 (8)
     *
     * Corresponds to `CurseID.UNKNOWN` (4).
     */
    readonly UNKNOWN: int;
    /**
     * 1 << 4 (16)
     *
     * Corresponds to `CurseID.CURSED` (5).
     */
    readonly CURSED: int;
    /**
     * 1 << 5 (32)
     *
     * Corresponds to `CurseID.MAZE` (6).
     */
    readonly MAZE: int;
    /**
     * 1 << 6 (64)
     *
     * Corresponds to `CurseID.BLIND` (7).
     */
    readonly BLIND: int;
    /**
     * 1 << 7 (128)
     *
     * Corresponds to `CurseID.GIANT` (8).
     */
    readonly GIANT: int;
};
type LevelCurseValue = BitFlag & {
    readonly __levelCurseBrand: symbol;
};
type LevelCurseType = {
    readonly [K in keyof typeof LevelCurseInternal]: LevelCurseValue;
};
export declare const LevelCurse: LevelCurseType;
export type LevelCurse = LevelCurseType[keyof LevelCurseType];
export declare const LevelCurseZero: BitFlags<LevelCurseValue>;
export {};
//# sourceMappingURL=LevelCurse.d.ts.map